.. _all-salt.runners:

===========================
Full list of runner modules
===========================

.. currentmodule:: salt.runners

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    cache
    doc
    jobs
    launchd
    manage
    network
    search
    state
    winrepo
